function [CR,mdat] = CRboundNoLinearize(RL,M)
% function [CR,mdat] = CRboundNoLinearize(RL,M)
%  Computes Cramer-Rao lower bound (CRLB) for log data 
%  directly from general formula for Fisher Info matrix
%  for general Gaussian case (Eq. 3.31 of Kay). Also assumes
%  independent Poisson counting detectors
%  inputs: 
%    RL: the covariance of the log of counts (nbins,nbins)
%    M: the effective attenuation coefficient matrix (nbins,2)
%  outputs:
%    CR: the CRLB 
%    mdat: debugging info struct. See code for fields
%  REA 10/1/10 - 2011-Jul-19 14:45   

[nbins,ndim] = size(M);
[r,c] = size(RL);
if any([r,c] ~= nbins)
   error('CRboundNoLinearize: RL matrix must be square with size=nbin');
end

F = zeros(ndim); % Fisher information matrix for A components

RLinv = inv(RL);
for i = 1:ndim
   for j= 1:ndim
     F(i,j) = M(:,i)'*RLinv*M(:,j) + 0.5*trace(RLinv*dCdAloc(RL,M,i)*RLinv*dCdAloc(RL,M,j));
   end
end
CR = inv(F);
mdat.CRlinear = inv(M'*inv(RL)*M);


% ------------ LOCAL FUNCTIONS --------
    function drv = dCdAloc(RL,M,i) 
       % implements partial derivative of covariance RL wrt A_i
       % see derivation on my paper  notebook (10/1/10): ToDo: enter into Onenote
    drv = -diag(diag(RL).*M(:,i));   