% P28Est4.m Estimation4
% COPYRIGHT:  Aprend Technology, 2011. All rights reserved.
 
%% init vars
post_title = 'P28Est4';
dirname = ['E:\Projects\Blog\Posts\' post_title '\'];

%% compare full CRLB to constant covariance term--create data
      % spectrum
tube_voltage = 120; % keV  
[specnum,xray_energies] = XrayTubeSpectrumTasmip(tube_voltage,'number_spectrum');
   % mu data
materials = {'Al','C5O2H8'};
rhos = [2.699 1.19];
mus =  [rhos(1)*xraymu(materials{1},xray_energies) rhos(2)*xraymu(materials{2},xray_energies)];
   % create the spectrum data (specdat) struct
nphotons = 10^7; % number of photons in incident beam  
specdat.specnum = nphotons*specnum(:)/sum(specnum(:)); % normalize so can adjust Ninit easily later
specdat.egys = xray_energies;
specdat.mus = mus;
   % pulse height analysis bin thresholds 
nbins = 5;
specdat.idx_threshold = OptimNbinsThresholds(specdat,nbins);
   % get data for diagonal line through A plane--first define As
npoints_on_line=  25;% number of points along line
ztest_line= linspace(0,0.9*(2.5 + 1i*30),npoints_on_line); % coords of points on line in A plane
    % mean values of data in PHA bins for points on the diagonal line
lambdas_line = PoissonLambda(ztest_line,specdat);
    % the effective M matrix for each thickness, nbins,2,numel(ztest_line) 
Ms_all = mubarNbin(specdat,ztest_line); 

%%  prep data for plot error versus thickness
A_names = {'A_1','A_2'};
CR_error_frac = zeros(npoints_on_line,1);
for kt = 1:npoints_on_line
        % the CR bound  and linear approximation
    M = Ms_all(:,:,kt);
    lambdas_pnt = lambdas_line(kt,:);
    RL = diag(1./lambdas_pnt);
    RA_CR = CRboundNoLinearize(RL,M);
    RA_CR_lin = inv(M'*inv(RL)*M); % the linear term of Cramer-Rao bound
    CR_error_frac(kt,:) = norm(RA_CR - RA_CR_lin)/norm(RA_CR); 
end

%% plot frac error vs distance from center
fh = figure;
linewid = 1.5;
subplot(121)
plot(ztest_line,'-.k','linewidth',linewid)
xlabel(A_names{1},'fontsize',14)
ylabel(A_names{2},'fontsize',14)
set(gca,'fontsize',12,'linewidth',linewid)
subplot(122)
plot(abs(ztest_line),CR_error_frac,'-k','linewidth',1.5);
axis([0 30 0 0.1])
% semilogy(abs(ztest_line),CR_error_frac,'-k','linewidth',1.5);
xlabel('object thickness','fontsize',12)
ylabel('norm( CRLB-CRLB_{lin} )/norm(CRLB)','fontsize',13)
set(gca,'fontsize',12,'linewidth',linewid)
set(fh,'color','w','position',[250 1000 800 450])

%% export the figure as png and eps
figno = sprintf('-f%d',fh);
fname = 'CRLBvsConstCov';
   % export as eps
exportfig(fh,[dirname fname '.eps'],'width',7,'LockAxes',0,'color','cmyk');
set(fh,'papertype','usletter')
print(figno,'-dpng','-cmyk','-r100',[dirname fname '.png']) % resolution 100 dpi
